
.. _api-ref:

=============
API reference
=============

This page gives an overview of all public Gammapy objects, functions and
methods. All classes and functions exposed in ``gammapy.*`` namespace are public.


.. toctree::
    :maxdepth: 1

    data
    irf
    makers
    datasets
    maps
    modeling
    estimators

    analysis
    catalog
    astro
    stats

    scripts
    visualization
    utils
